@@ -2,6 +2,7 @@ from __future__ import print_function
 import io
 import os
 import platform
+import socket
 import sys
 
 from eel import chrome
@@ -57,3 +58,12 @@ def get_warnings():
         })
 
     return warnings
+
+
+def get_port():
+    """ Get an available port by starting a new server, stopping and and returning the port """
+    sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+    sock.bind(('localhost', 0))
+    port = sock.getsockname()[1]
+    sock.close()
+    return port
